@@ -84,7 +84,7 @@ calc_CommonDose <- function(
            'data.frame' or 'RLum.Results'!")
     }else{
       if(is(data, "RLum.Results") == TRUE){
-        data <- get_RLum(data, signature(object = "De.values"))
+        data <- get_RLum(data, "data")
       }
     }
   }
