@@ -32,7 +32,7 @@
 #' the output data depends on the user.\cr\cr The validity of the file path is
 #' not further checked. \cr BIN-file conversions using the argument
 #' \code{version} may be a lossy conversion, depending on the chosen input and
-#' output data (e.g., conversion from version 07 to 06 to 04 or 03).\cr
+#' output data (e.g., conversion from version 08 to 07 to 06 to 04 or 03).\cr
 #'
 #' \bold{Warning}\cr
 #'
@@ -42,23 +42,26 @@
 #' BIN/BINX-file may not fully compatible, at least not similar to the once
 #' directly produced by the Risoe readers!\cr
 #'
-#' Implementation of support for version 07 could so far not properly tested.
-#'
-#' @section Function version: 0.3.3
+#' @section Function version: 0.4.0
 #'
 #' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montaigne
 #' (France)
 #'
+#' @note ROI definitions (introduced in BIN-file version 8) are not supported! There are furthermore
+#' ignored by the function \code{\link{read_BIN2R}}.
+#'
 #' @seealso \code{\link{read_BIN2R}}, \code{\linkS4class{Risoe.BINfileData}},
 #' \code{\link{writeBin}}
 #'
-#' @references Duller, G., 2007. Analyst.
+#' @references
+#'
+#' DTU Nutech, 2016. The Squence Editor, Users Manual, February, 2016.
+#' \url{http://www.nutech.dtu.dk/english/Products-and-Services/Dosimetry/Radiation-Measurement-Instruments/TL_OSL_reader/Manuals}
 #'
 #' @keywords IO
 #'
 #' @examples
 #'
-#'
 #' ##uncomment for usage
 #'
 #' ##data(ExampleData.BINfileData, envir = environment())
@@ -76,7 +79,7 @@ write_R2BIN <- function(
   # Config ------------------------------------------------------------------
 
   ##set supported BIN format version
-  VERSION.supported <- as.raw(c(3, 4, 6, 7))
+  VERSION.supported <- as.raw(c(3, 4, 6, 7, 8))
 
   # Check integrity ---------------------------------------------------------
 
@@ -88,7 +91,7 @@ write_R2BIN <- function(
   }
 
   ##check if it fullfills the last definition
-  if(ncol(object@METADATA)!=71){
+  if(ncol(object@METADATA)!=80){
 
     stop("[write_R2BIN()] The number of columns in your slot 'METADATA' does not fit to the latest definition. What you are probably trying to do is to export a Risoe.BINfileData object you generated by your own or you imported with an old package version some time ago. Please re-import the BIN-file using the function read_BIN2R().")
 
@@ -124,6 +127,7 @@ write_R2BIN <- function(
 
       ##stepping decision
       header.stepping <- switch(as.character(version),
+                                "08" = 507,
                                 "07" = 447,
                                 "06" = 447,
                                 "04" = 272,
@@ -150,9 +154,9 @@ write_R2BIN <- function(
   }
 
   ##check whether this file can be exported without problems due to the latest specifications
-  if(ncol(object@METADATA) != 71){
+  if(ncol(object@METADATA) != 80){
 
-    stop("[write_R2BIN()] Your Risoe.BINfileData object seems not be compatible with the latest specification of this S4-class object. You are probably trying to export a Risoe.BINfileData from your workspace you produced manually ")
+    stop("[write_R2BIN()] Your Risoe.BINfileData object seems not be compatible with the latest specification of this S4-class object. You are probably trying to export a Risoe.BINfileData from your workspace you produced manually or with an old version.")
 
   }
 
@@ -169,7 +173,7 @@ write_R2BIN <- function(
   }
 
   ##CHECK file name for version == 06 it has to be *.binx and correct for it
-  if(version == 06 | version == 07){
+  if(version == 06 | version == 07 | version == 08){
 
     ##grep file ending
     temp.file.name <- unlist(strsplit(file, "[:.:]"))
@@ -805,7 +809,7 @@ write_R2BIN <- function(
   ## ====================================================
   ## version 06
 
-  if(version == 06 | version == 07){
+  if(version == 06 | version == 07 | version == 08){
 
     ##start loop for export BIN data
     while(ID<=n.records) {
@@ -830,6 +834,12 @@ write_R2BIN <- function(
                size = 4,
                endian="little")
 
+      if(version == 08){
+        writeBin(object@METADATA[ID,"RECTYPE"],
+                 con,
+                 size = 1,
+                 endian="little")
+      }
 
       ##RUN, SET, POSITION, GRAINNUMBER, CURVENO, XCOORD, YCOORD
       writeBin(c(as.integer(object@METADATA[ID,"RUN"]),
@@ -1134,7 +1144,7 @@ write_R2BIN <- function(
                endian="little")
 
       ##ONTIME, STIMPERIOD
-      writeBin(c(as.integer(object@METADATA[ID,"ONTIME"]),
+      writeBin(c(suppressWarnings(as.integer(object@METADATA[ID,"ONTIME"])),
                  as.integer(object@METADATA[ID,"STIMPERIOD"])),
                con,
                size = 4,
@@ -1222,20 +1232,62 @@ write_R2BIN <- function(
                  endian="little")
 
 
-        ##RESERVED 2
-        if(length(object@.RESERVED) == 0 || version.original != version){
-          writeBin(raw(length=15),
-                   con,
-                   size = 1,
-                   endian="little")
+        ##VERSION 08
+        if(version == 07){
+
+          ##RESERVED 2
+          if(length(object@.RESERVED) == 0 || version.original != version){
+            writeBin(raw(length=15),
+                     con,
+                     size = 1,
+                     endian="little")
+          }else{
+
+            writeBin(object@.RESERVED[[ID]][[2]],
+                     con,
+                     size = 1,
+                     endian="little")
+          }
+
+
         }else{
 
-          writeBin(object@.RESERVED[[ID]][[2]],
-                   con,
-                   size = 1,
-                   endian="little")
+          ##MARKPOS POSITION and extraction
+          writeBin(
+            c(
+              as.double(object@METADATA[ID, "MARKPOS_X1"]),
+              as.double(object@METADATA[ID, "MARKPOS_Y1"]),
+              as.double(object@METADATA[ID, "MARKPOS_X2"]),
+              as.double(object@METADATA[ID, "MARKPOS_Y2"]),
+              as.double(object@METADATA[ID, "MARKPOS_X3"]),
+              as.double(object@METADATA[ID, "MARKPOS_Y3"]),
+              as.double(object@METADATA[ID, "EXTR_START"]),
+              as.double(object@METADATA[ID, "EXTR_END"])
+            ),
+            con,
+            size = 4,
+            endian = "little"
+          )
+
+
+          ##RESERVED 2
+          if(length(object@.RESERVED) == 0 || version.original != version){
+            writeBin(raw(length=42),
+                     con,
+                     size = 1,
+                     endian="little")
+          }else{
+
+            writeBin(object@.RESERVED[[ID]][[2]],
+                     con,
+                     size = 1,
+                     endian="little")
+          }
+
+
         }
 
+
       }#end if version decision
 
       ##DPOINTS
